function [PFT, LUT, nLw, chl_lut]=modis_physat(Rrs412,Rrs443,Rrs469,Rrs488,Rrs531,Rrs547,Rrs555, aot, chl, optLUT)
% [PFT]=modis_physat(Rrs412,Rrs443,Rrs469,Rrs488,Rrs531,Rrs547,Rrs555, aot, chl, optLUT)
% 
% Phytoplancton Funtional Types folowing PHYSAT method (Alvain et al.,
% 2008). Look Up Table (LUT - relationships between RrsXXX vs Clorophyll)
% used by default come from Navarro et al. (2014). Regional LUTs can be
% calculated and used as an option. 
% 
% INPUTS:
% RrsXXX    Remote-sensing reflectances observed by the satellite
%           instrument after atmospheric correction. Rrs are trasformed to
%           Normalized water-leaving radiances for the 412, 443, 488, 531,  
%           555 wavelength (nn) 
% aot       Aerosol optical tickness in 869 nn. 
% chl       Chlorophyll concentration (mg m-3)
% optLUT    [1|2]. If optLUT==1 then PTF will be performded using LUT from
%           Navarro et al. (2014). If optLUT==2 then a regional LUT will be
%           calculated. 
%
% OUTPUTS:
% PFT       Matriz with the indices of domiant Phytoplancton Functional
%           Types:
%           (1) Nanoeucaryotes
%           (2) Prochloroccocus
%           (3) Synechococcus
%           (4) Diatoms
%           (5) Phaeocystis-like
%           (6) Coccolithophorids bloom
% 
% Discalimer: The function modis_physat.m is an unauthorized implementation
% of PHYSAT method developed by Alvain et al. (2005, 2008, 2012). Please
% use it as reference and cite the original developers.  
%
% Marco Correa (marco.correa.r@gmail.com)
% Last Modification: 10.08.2015

save A

% nLw (incorporando las radianzas solares)
nLw412=Rrs412*172.9120; 
nLw443=Rrs443*187.6220; 
nLw469=Rrs469*205.8780; 
nLw488=Rrs488*194.9330;
nLw531=Rrs531*185.7470; 
nLw547=Rrs547*186.5390;
nLw555=Rrs555*183.8690;
%clear Rrs*

% ----------------------------------------------
% Empirical Look-Up-Table
if optLUT==1
    load /media/procesos/PHYSAT/LUT_PHYSAT_2011-11_MODIS.txt
    %load('/media/marco/TOSHIBA EXT/procesos/PHYSAT/LUT_PHYSAT_2011-11_MODIS.txt')
    LUT= LUT_PHYSAT_2011_11_MODIS;
    chl_lut=LUT(:,1);LUT=LUT(:,2:end);
    % longitudes de onda
    nLw=[412 443 488 531 555];
    iaot=find(aot<.15 & chl<=max(chl_lut)); % indice aot
    
    % Acceptable Radiance Anomalies spectra for each phytoplankton groups.
    Ra=[0.4000    0.5500    0.6000    0.6000    0.6000
        0.8000    0.9000    0.9500    1.0000    1.0000
        0.8000    0.9000    0.9000    0.9000    0.9000
        1.0000    1.0000    1.0000    1.0000    1.0000
        1.0000    1.0000    1.0000    1.0000    1.0000
        1.2000    1.2000    1.1500    1.1500    1.1500
        1.2000    1.2000    1.1500    1.1500    1.1500
        2.2000    1.8000    1.5000    1.4000    1.4000
        1.3000    1.4000    1.4000    1.4000    1.4000
        1.5000    1.6000    1.6000    1.6000    1.6000
        2.5000    2.5000    2.5000    2.5000    2.5000
        6.0000    6.0000    6.0000    6.0000    6.0000];
    
    % Matrix of normalized water-leaving radiances
    nLwS= [nLw412(iaot) nLw443(iaot) nLw488(iaot) nLw531(iaot) nLw555(iaot)];
    %nLwS= [R412(iaot) R443(iaot) R488(iaot) R531(iaot) R555(iaot)];
end

% ----------------------------------------------
% Regional Look-Up-Table
if optLUT==2
    nLw=[412 443 469 488 531 547 555 ];
    
    % limites dominio
    rchl=min(chl(:));
    schl=nanmean(chl(:))+nanstd(chl(:))*4
    
    iaot=find(aot<.15 & chl<=schl & nLw555<1.3); % indice aot y turbidez
    % Matrix of normalized water-leaving radiances
    nLwS=[nLw412(iaot) nLw443(iaot) nLw469(iaot) nLw488(iaot) nLw531(iaot) nLw547(iaot) nLw555(iaot)];
    %nLwS= [R412(iaot) R443(iaot) R488(iaot) R531(iaot) R555(iaot)];
    
    chl_lut=rchl:.01:schl;
    chl1=chl(iaot);
    LUT=[];
    
    % Moving trasnlaping box of 0.3 mg m-3
    for i=1:length(chl_lut)
%         cont=0; 
%         for j=1:10;  % ampliando rango si no encuentra datos
%             cont=cont+1;
%             a=find(chl1>chl_lut(i)-.02*cont & chl1<=chl_lut(i)+.02*cont);
%             if length(a)>1; break; end
%         end
        a=find(chl1>=chl_lut(i)-.01 & chl1<=chl_lut(i)+.01);
        LUT(i, :)=nanmean(nLwS(a, :));
    end
    figure; pcolor(LUT); shading flat
    % Quitando rangos sin datos
    a=find(isnan(sum(LUT,2))); LUT(a,:)=[]; chl_lut(a)=[];
    
    % Ajustando polinomio
    warning off
    for i=1:length(nLw)
        a=find(~isnan(LUT(:,i)));
        p=polyfit(chl_lut(a)', LUT(a,i),20);
        A=polyval(p, chl_lut);
        LUT(:,i)=A;
    end
    warning on 
    
      
    % Acceptable Radiance Anomalies spectra for each phytoplankton groups
    % (Navarro et al.,2014).
    Ra=[0.4000    0.5500    0.5777    0.5979    0.6000    0.6000    0.6000
        0.8000    0.9000    0.9277    0.9479    1.0000    1.0000    1.0000
        0.8000    0.9000    0.9000    0.9000    0.9000    0.9000    0.9000
        1.0000    1.0000    1.0000    1.0000    1.0000    1.0000    1.0000
        1.0000    1.0000    1.0000    1.0000    1.0000    1.0000    1.0000
        1.2000    1.2000    1.1723    1.1521    1.1500    1.1500    1.1500
        1.2000    1.2000    1.1723    1.1521    1.1500    1.1500    1.1500
        2.2000    1.8000    1.6340    1.5128    1.4000    1.4000    1.4000
        1.3000    1.4000    1.4000    1.4000    1.4000    1.4000    1.4000
        1.5000    1.6000    1.6000    1.6000    1.6000    1.6000    1.6000
        2.5       2.5      2.5        2.5     2.5         2.5     2.5
        6         6       6           6        6         6       6];
    
end


% Look-Up-Table of nLw_ref for each given Chl-a concentration
lut=interp2(nLw, chl_lut, LUT,nLw,chl(iaot));

% Radiance anomalies
nLwS=nLwS./lut;


pft=iaot*nan;
for i=1:6
    Ab=repmat(Ra(i*2-1,:), length(iaot), 1); Ab=nLwS-Ab;
    At=repmat(Ra(i*2,:), length(iaot), 1); At=At-nLwS;
    
    % indice para grupos sin condiciones adicionales
    a=find( all(Ab>0, 2) & all(At>0, 2));

    pft(a)=i;
end

PFT=chl*nan; PFT(iaot)=pft;








