function [PFT, U1, U2, modevar, U1S, U2S, ai, pftnom]=modis_phystwo(Rrs412,Rrs443,Rrs469,Rrs488,Rrs531,Rrs547,Rrs555, aot, chl, model)
% [PFT, U1, U2, modevar, U1S, U2S, ai, pftnom]=modis_phystwo(Rrs412,Rrs443,Rrs469,Rrs488,Rrs531,Rrs547,Rrs555, aot, chl, model)
% 
% Phytoplancton Funtional Types using a EOF based aproximation
% (Correa-Ramires et al., in prep). Dominan epectral efect of chlorophyll
% is aisolaeted in the first mode M1 from a orthogonal decomposition. Then
% the second mode M2 correspond to the spectral signal of the other
% non-chlorophyll, accesory pigments) biomarkers of PFT.   
% 
% INPUTS:
% RrsXXX    Remote-sensing reflectances observed by the satellite
%           instrument after atmospheric correction.  Rrs are trasformed to
%           Normalized water-leaving radiances for the 412, 443, 488, 531, 
%           555 wavelength (nn) 
% aot       Aerosol optical tickness in 869 nn. 
% chl       Chlorophyll concentration (mg m-3)
% model     [1|2] Model used: [1] Physat derived or [2] Physat modify model
%
% OUTPUTS:
% PFT       Matriz with the indices of domiant Phytoplancton Functional
%           Types:
%           (1) Nanoeucaryotes
%           (2) Prochloroccocus
%           (3) Synechococcus
%           (4) Diatoms
%           (5) Phaeocystis-like
%           (6) Coccolithophorids bloom
% U2        Spatial pattern of the secon spectral mode
% M2        Second spectral mode
%  
%
% Marco Correa (marco.correa.r@gmail.com)
% Last Modification: 20.09.2016

% nLw (incorporing solar radiances)
nLw412=Rrs412*172.9120; 
nLw443=Rrs443*187.6220; 
nLw469=Rrs469*205.8780; 
nLw488=Rrs488*194.9330;
nLw531=Rrs531*185.7470; 
nLw547=Rrs547*186.5390;
nLw555=Rrs555*183.8690;
%clear Rrs*

% Incorporing sinthetic matrix
tic
if model==1
    load PHYSTWO_synthetic_matrix.mat MS chls ai
end

if model==2
    load PHYSTWO_synthetic_matrix_adjusted.mat QS ai nLw
    MS=QS; clear QS
end

% size
[z1,z2]=size(MS);

% excluding Rows from the R matrix in the positions where nLw(555) was >1.3
% W m-2 μm-1 sr-1 and AOT was >0.15, in order to reduce the presence of
% biased values arising from high concentrations of suspended sediments or
% by errors in the atmospheric correction, as recommended by both Navarro
% et al. (2014)    
iaot=find(aot<.15 | nLw555<1.3); 

zd=length(iaot); % Tamaño indice de datos

% Matrix of normalized water-leaving radiances
nLwS=[nLw412(iaot) nLw443(iaot) nLw469(iaot) nLw488(iaot) nLw531(iaot) nLw547(iaot) nLw555(iaot)];

% Matriz Concatenation 
P=[nLwS;MS]; 

% stadistical normalization
vm=nanmean(P); vs=nanstd(P) ;
vm2=repmat(vm,size(P,1),1); vs2=repmat(vs,size(P,1),1);
P=(P-vm2)./vs2;

% Removing artifacts 
P(isinf(P))=0;

% SVD decomposition
[U,S,V] = svd((P), 0);

% Variance by modes
L=(diag(S)).^2;
pvar=L./sum(L).*100;
modevar=pvar(1:2);
disp('PHYSTWO - Phytoplanckton Functional Types ');
disp('based on a Second Order EOF decomposition');
disp([' > Data analized : ' num2str(zd)]);
disp([' > Data excluded : ' num2str(100-zd./(sum(~isnan(chl(:))))*100, '%3.1f') '%']);
disp([' > VarExplained Mode 1 : ' num2str(pvar(1), '%3.1f') '%' ]);
disp([' > VarExplained Mode 2 : ' num2str(pvar(2), '%3.1f') '%' ]);
if model==1; disp([' > Orthomodels : UNADJUSTED' ]);end
if model==2; disp([' > Orthomodels : ADJUSTED' ]);end

% spatial patterns by modes
U1=U(1:zd,1); % mode 1 (chlorophyll)
U2=U(1:zd,2); % mode 2 (spectral sucesion)
U3=U(1:zd,3); % mode 3

% spatial patterns of sinthetic matrix 
a=zd+1: zd+z1;
U2S=U(a,2);
U3S=U(a,3);
U1S=U(a,1);

% color map
h2=[ 0.5  0.5 0.5; 0 0 1; 0 1 1; 1 1 0; 1 0 0; .5 0 0];

pft=iaot*nan;

if model==1
    for i=1:zd
        d=sqrt( (U(i,1)-U1S).^2 + (U(i,2)-U2S).^2 );
        [a,b]=min(d);
        pft(i)=ceil(b/300);
    end
    
    %[a,I]=min(C2);
    %PFT=chl*nan; PFT(iaot)=C2;
end


if model==2
    C2=pft;
    for i=1:zd
        b=sqrt( (U1(i)-U1S).^2 + (U2(i)-U2S).^2 );
        [a,b]=min(b);
        C2(i)=b;
    end
    
    for i=1:6
        a=find(C2>=ai(i,1) & C2<=ai(i,2));
        pft(a)=i;
    end
    
end

% re-arange in a 2D matrix
PFT=chl*nan; PFT(iaot)=pft;
A=U1; U1=chl*nan; U1(iaot)=A; 
A=U2; U2=chl*nan; U2(iaot)=A; 
pftnom={'(1) Nanoeucaryotes', '(2) Prochloroccocus', '(3) Synechococcus',...
    '(4) Diatoms', '(5) Phaeocystis-like', '(6) Coccolithophorids bloo'};
% U2=chl*nan; U2(iaot)=U(1:zd,2);
disp(['Done in ' num2str(toc, '%3.0f') 's']);



